#
# spec file for package perl-Term-ProgressBar
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Term-ProgressBar
Name:           perl-Term-ProgressBar
Version:        2.23
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Provide a progress meter on a standard terminal
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MANWAR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.13
BuildRequires:  perl(Class::MethodMaker) >= 1.02
BuildRequires:  perl(Term::ReadKey) >= 2.14
BuildRequires:  perl(Test::Exception) >= 0.310000
BuildRequires:  perl(Test::More) >= 0.80
BuildRequires:  perl(Test::Warnings)
Requires:       perl(Class::MethodMaker) >= 1.02
Requires:       perl(Term::ReadKey) >= 2.14
%{perl_requires}

%description
Term::ProgressBar provides a simple progress bar on the terminal, to let
the user know that something is happening, roughly how much stuff has been
done, and maybe an estimate at how long remains.

A typical use sets up the progress bar with a number of items to do, and
then calls update to update the bar whenever an item is processed.

Often, this would involve updating the progress bar many times with no
user-visible change. To avoid unnecessary work, the update method returns a
value, being the update value at which the user will next see a change. By
only calling update when the current value exceeds the next update value,
the call overhead is reduced.

Remember to call the '$progress->update($max_value)' when the job is done
to get a nice 100% done bar.

A progress bar by default is simple; it just goes from left-to-right,
filling the bar with '=' characters. These are called *major* characters.
For long-running jobs, this may be too slow, so two additional features are
available: a linear completion time estimator, and/or a *minor* character:
this is a character that _moves_ from left-to-right on the progress bar (it
does not fill it as the major character does), traversing once for each
major-character added. This exponentially increases the granularity of the
bar for the same width.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README

%changelog
* Sun Oct  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.23
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.23  2022-10-08 MANWAR
  - Merged PR #11: Added a check to print a full bar at the end, thanks @cwallacetlc.
* Sun May 13 2018 coolo@suse.com
- updated to 2.22
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.22  2018-05-12 MANWAR
  - Merged PR #10: Amend to prevent uninitialised warning error, thanks @lharey.
* Thu Aug  3 2017 coolo@suse.com
- updated to 2.21
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.21  2017-08-02 MANWAR
  - Added key 'clean' to Makefile.PL script.
* Wed Jul 12 2017 coolo@suse.com
- updated to 2.20
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.20  2017-07-11 MANWAR
  - silent mode avoids uninitialized value messages (GFIREBALL)
* Tue Jul 11 2017 coolo@suse.com
- updated to 2.19
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.19  2017-07-10 MANWAR
  - Fixed inconsistent version as reported by CPANTS.
* Wed Dec  7 2016 coolo@suse.com
- updated to 2.18
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
* Mon Apr 13 2015 coolo@suse.com
- updated to 2.17
  see /usr/share/doc/packages/perl-Term-ProgressBar/Changes
  2.17 2015-01-23
  - Handle case when the maximum number of items is unknown (LukeGoodsell)
  2.16 2014-09-09 17:00:00
  - Cygwin width issue  RT #8344 (LukeGoodsell)
  - Remove unused DEBUG variables.
  - Stop exorting $PACKAGE $VERSION.
  - Add use warnings;
* Wed Jun 25 2014 mlatimer@suse.com
- Update to version 2.15
  + Add Term::ProgressBar::IO, which displays a progress bar while reading
    from a seekable filehandle
* Wed Aug  7 2013 rcurtis@suse.com
- Removed Requires: perl and BuildRequires: perl from spec file
* Tue Aug  6 2013 rcurtis@suse.com
- Updated spec file to replace perl_requires macro with preferred SUSE
  Requires:  perl >= x.x format
* Tue Aug  6 2013 rcurtis@suse.com
- Updated spec file to remove %%perl_requires macro
* Fri Aug  2 2013 rcurtis@suse.com
- Validated that license is 'per' as listed in Makefile.PL which is GPL or
  Artistic compliant. The spec file reflects this change.
* Fri Aug  2 2013 rcurtis@suse.com
- Updated spec file to remove auto/Term-ProgressBar from the files section
  that is no longer used in the new version. Removed the BUGS file from the
  files section in spec file since all changes are not logged in changes
* Fri Aug  2 2013 rcurtis@suse.com
- Updated spec files section for 2.14 version
* Fri Aug  2 2013 rcurtis@suse.com
- Trying newerv 2.13 version
* Fri Aug  2 2013 rcurtis@suse.com
- Checked license and updated spec.  Module states same license as Perl which
  is GPL-1.0+ or Artistic-1.0
* Thu Aug  1 2013 rcurtis@suse.com
- reverted back to 2.12 due to build options
* Thu Aug  1 2013 rcurtis@suse.com
- added Term-ProgressBar-2.14.tar.gz in place of Term-ProgressBar-2.10.tar.gz
* Thu Aug  1 2013 rcurtis@suse.com
- update to 2.14:
  * updated spec file to version 2.14
* Wed Dec 21 2011 pascal.bleser@opensuse.org
- update to 2.10:
  * remove Build.PL (keep the Makefile.PL only)
  * replace home-made testing tools with CPAN-ish tools
  * require Capture::Tiny for testing
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Nov 29 2010 coolo@novell.com
- called spec2changelog
* Tue Jun 20 2006 jfunk@funktronics.ca
- Build under buildservice
* Fri Nov 11 2005 jfunk@funktronics.ca
- Build for SL10
* Thu May 12 2005 jfunk@funktronics.ca
- Update
- Build for SL93
* Fri Nov 19 2004 jfunk@funktronics.ca
- Build for SL92
* Tue May 11 2004 jfunk@funktronics.ca
- Update
- Build for SL91
* Tue Nov  4 2003 jfunk@funktronics.ca
- Update
- Build for SUSE 9.0
* Fri May 30 2003 jfunk@funktronics.ca
- Update
- Build for SuSE 8.2
* Wed Dec 11 2002 jfunk@funktronics.ca
- Update to 2.02
- Build for SuSE 8.1
* Thu May 30 2002 jfunk@funktronics.ca
- Initial build with new spec layout
